@@ -14,29 +14,67 @@
  *
  *-------------------------------------------------------------------------
  */
+#include "pqxx/compiler.h"
+
 #include <stdexcept>
 
 #include "pqxx/binarystring"
 
-using namespace std;
+using namespace PGSTD;
+
+namespace
+{
+// Convert textual digit to value
+inline char DV(unsigned char d) { return d - '0'; }
+}
 
 pqxx::binarystring::binarystring(const result::field &F) :
   super(),
   m_size(0)
 {
-  size_t sz = 0;
   unsigned char *p = const_cast<unsigned char *>(
       reinterpret_cast<const_iterator>(F.c_str()));
+
+#ifdef PQXX_HAVE_PQUNESCAPEBYTEA
+
+  size_t sz = 0;
   super::operator=(PQunescapeBytea(p, &sz));
   // TODO: More useful error message--report cause of the problem!
   if (!c_ptr()) throw runtime_error("Unable to read bytea field");
   m_size = sz;
+
+#else
+
+  m_str.reserve(F.size());
+  for (result::field::size_type i=0; i<F.size(); ++i)
+  {
+    unsigned char c = p[i];
+    if (c == '\\')
+    {
+      c = p[++i];
+      if (isdigit(c) && isdigit(p[i+1]) && isdigit(p[i+2]))
+      {
+	c = (DV(p[c])<<9) | (DV(p[i+1])<<3) | DV(p[i+2]);
+	i += 2;
+      }
+    }
+    m_str += char(c);
+  }
+
+  m_size = m_str.size();
+  void *buf = malloc(m_size+1);
+  if (!buf)
+    throw bad_alloc();
+  super::operator=(static_cast<unsigned char *>(buf));
+  strcpy(static_cast<char *>(buf), m_str.c_str());
+
+#endif
 }
 
 
 pqxx::binarystring::const_reference pqxx::binarystring::at(size_type n) const
 {
-  if ((n < 0) || (n >= m_size))
+  if (n >= m_size)
   {
     if (!m_size)
       throw out_of_range("Accessing empty binarystring");
@@ -56,6 +94,7 @@ const string &pqxx::binarystring::str() const
 
 string pqxx::escape_binary(const unsigned char bin[], size_t len)
 {
+#ifdef PQXX_HAVE_PQUNESCAPEBYTEA
   size_t escapedlen = 0;
   unsigned char *p = const_cast<unsigned char *>(bin);
   PQAlloc<unsigned char> A(PQescapeBytea(p, len, &escapedlen));
@@ -63,6 +102,37 @@ string pqxx::escape_binary(const unsigned char bin[], size_t len)
   // TODO: Find out the nature of the problem, if any!
   if (!cstr) throw runtime_error("Could not escape binary string!");
   return string(cstr, escapedlen-1);
+#else
+  string result;
+  result.reserve(len);
+  for (size_t i=0; i<len; ++i)
+  {
+    if (bin[i] & 0x80)
+    {
+      char buf[8];
+      sprintf(buf, "\\\\%03o", unsigned(bin[i]));
+      result += buf;
+    }
+    else switch (bin[i])
+    {
+    case 0:
+      result += "\\\\000";
+      break;
+
+    case '\'':
+      result += "\\'";
+      break;
+
+    case '\\':
+      result += "\\\\\\\\";
+      break;
+
+    default:
+      result += char(bin[i]);
+    }
+  }
+  return result;
+#endif
 }
 
 string pqxx::escape_binary(const unsigned char bin[])
